#include "States/SelectState.h"
#include "States/ExitState.h"

SelectState::SelectState(IStateManager& state_manager, const sf::VideoMode& video_mode, const std::string& window_title):
        IWindowKeeper(video_mode, window_title), IState(state_manager), m_menu(state_manager) {}

bool SelectState::do_step() {
    event_handling();
    update();
    render();
    return true;
}

void SelectState::event_handling() {
    sf::Event event;
    while (m_window.pollEvent(event)) {
        if (event.type == sf::Event::Closed) {
            m_state_manager.set_next_state(std::make_unique<ExitState>(m_state_manager));
            break;
        }
        if (event.type == sf::Event::Resized) {
            sf::View view = m_window.getView();
            view.setSize(event.size.width, event.size.height);
            m_window.setView(view);
        }
    }
}

void SelectState::update() {
    sf::Vector2f pos = m_window.mapPixelToCoords(sf::Mouse::getPosition(m_window));
    bool is_pressed = sf::Mouse::isButtonPressed(sf::Mouse::Button::Left);
    m_menu.process_mouse(pos, is_pressed);
}

void SelectState::render() {
    m_window.clear(config::SELECT_LEVEL_BACKGROUND_COLOR);
    m_menu.draw_into(m_window);
    m_window.display();
}